@@ -62,7 +62,8 @@ class Strategy(object):
     def __rebuild_event_data(self, event_data):
         if event_data is None:
             return
-        event_data.symbol = '{0}.{1}'.format(event_data.symbol, event_data.exchange)
+        if hasattr(event_data,'symbol') and '.' not in event_data.symbol:
+                event_data.symbol = '{0}.{1}'.format(event_data.symbol, event_data.exchange.name)
 
     def handle_open(self, event):
         if event is None or event.raise_time is None:
@@ -90,7 +91,7 @@ class Strategy(object):
             return
         raise_time = event.raise_time + datetime.timedelta(hours=-1)
         for x in open_times:
-            if raise_time >= x.begin and raise_time <= x.end:
+            if raise_time >= datetime.datetime.strptime(x.begin,'%Y%m%d%H%M%S') and raise_time <= datetime.datetime.strptime(x.end,'%Y%m%d%H%M%S'):
                 logger.info("begin on_close")
                 self.__handle_close(self.__user_context)
                 logger.info("on_close complated")
