@@ -23,15 +23,15 @@ def on_init(ctx):
 
     account = ctx.get_account()
 
-    orders = ctx.get_orders()
+    orders = ctx.get_open_orders()
 
     positions = ctx.get_positions()
 
     trades = ctx.get_trades()
 
-    order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.LMT,Offset.Open,3530,3)
+    order = ctx.insert_order('rb2010.SHFE',OrderSide.Buy,OrderType.MKT,Offset.Open,0,3)
 
-    order1 = ctx.cancel_order(order)
+    #order1 = ctx.cancel_order(order)
 
     order2 = ctx.get_order(order.order_id)
 
