@@ -48,7 +48,7 @@ class MarketApi(IMarketApi):
                 subRet = self.Subscribe(*self.__subscribes)
                 logger.debug("连接成功，订阅完成：{0}".format(subRet))
         except Exception as e:
-            logger.error(e)
+            logger.error('subscribe market exception',e)
 
     def __OnRecv(self,msg):
         '''收到行情消息'''
