@@ -11,7 +11,7 @@ logger.setLevel(logging.INFO)
 logformat = logging.Formatter('%(asctime)-15s %(levelname)s [%(filename)s:%(lineno)d] %(message)s')
 
 console_handler = logging.StreamHandler(stream=sys.stdout)
-console_handler.setLevel(logging.INFO)
+console_handler.setLevel(logging.DEBUG)
 console_handler.setFormatter(logformat)
 logger.addHandler(console_handler)
 
@@ -20,7 +20,7 @@ def log2file(filename):
     if not os.path.exists(path):
         os.makedirs(path)
     file_handler = logging.FileHandler(filename)
-    file_handler.setLevel(logging.INFO)
+    file_handler.setLevel(logging.DEBUG)
     file_handler.setFormatter(logformat)
     logger.addHandler(file_handler)
 
